==> lpc4.05.09.tar.gz: lpc4/src/func_spec.c <==
#include "config.h"
/*
 * This file specifies types and arguments for efuns.
 * An argument can have two different types with the syntax 'type1 | type2'.
 * An argument is marked as optional if it also takes the type 'void'.
 */

/*
 * These values are used by the stack machine, and can not be directly
 * called from LPC.
 */
%token F_POP_VALUE F_DUP F_MARK
%token F_PUSH_IDENTIFIER_LVALUE F_PUSH_LOCAL_VARIABLE_LVALUE
%token F_PUSH_INDEXED_LVALUE F_INDIRECT F_INDEX F_CONSTANT F_SHORT_CONSTANT
%token F_CONST0 F_CONST1 F_PUSH_LTOSVAL F_PUSH_COST F_SWAP
%token F_LOCAL_NAME F_CONST_1 F_BYTE F_NEG_BYTE F_SHORT
%token F_BRANCH F_BRANCH_WHEN_ZERO F_BRANCH_WHEN_NON_ZERO
%token F_SHORT_BRANCH F_SHORT_BRANCH_WHEN_ZERO F_SHORT_BRANCH_WHEN_NON_ZERO

/*
 * These are the predefined functions that can be accessed from LPC.
 */

%token F_IDENTIFIER F_RETURN F_STRING F_SHORT_STRING
%token F_INC F_DEC F_POST_INC F_POST_DEC
%token F_INC_AND_POP F_DEC_AND_POP F_POP_N_ELEMS F_DUMB_RETURN
%token F_NUMBER F_ASSIGN F_ASSIGN_AND_POP F_ADD F_SUBTRACT F_MULTIPLY

%token F_DIVIDE F_LT F_GT F_EQ F_GE F_LE F_NE F_NEGATE F_NOT F_MOD
%token F_COMPL F_AND F_OR F_XOR F_LSH F_RSH F_LAND F_LOR

%token F_SWITCH F_SSCANF F_CAST_TO_OBJECT
%token F_INC_LOOP F_DEC_LOOP F_CAST_TO_STRING
%token F_INC_NEQ_LOOP F_DEC_NEQ_LOOP F_SWAP_VARIABLES

%token F_CATCH F_CAST_TO_FUNCTION F_PUSH_ARRAY
%token F_FOREACH F_CAST_TO_INT F_CAST_TO_FLOAT F_FLOAT
%token F_PUSH_SIMUL_EFUN F_TAILRECURSE
%token F_CONSTANT_FUNCTION F_SHORT_CONSTANT_FUNCTION
/* %token F_PARSE_COMMAND */

/* Object handling */
object this_object();
side_fx object clone_object(string);
side_fx void destruct(object|void);
side_fx void move_object(object);
side_fx string make_object(string);
side_fx object present(string|object, object default: F_THIS_OBJECT);
object first_inventory(object default: F_THIS_OBJECT);
object next_inventory(object default: F_THIS_OBJECT);
object *all_inventory(object default: F_THIS_OBJECT);
object *deep_inventory(object default: F_THIS_OBJECT);
object environment(void|object);
object next_clone(object|string);
int created(object);
int object_cpu(object);
int clone_number(object);
object *top_cpu(void);
object master();
object previous_object();
object *previous_objects();
object initiating_object();
string file_name(object default: F_THIS_OBJECT);

/* Object hash */
string hash_name(object);
object find_object(string);

/* Program handling */
string function_exists(string, object default: F_THIS_OBJECT);
string *inherit_list(object default: F_THIS_OBJECT);
side_fx int load(string);
side_fx int update(string);

/* String functions */
const string *explode(string, string);
const string implode(string *, string);
#ifdef USE_SPRINTF
side_fx string sprintf(string, ...);
#endif
const string lower_case(string);
const string capitalize(string);
const int strstr(string,string,void|int);
const string upper_case(string);
const mixed replace(string|mixed *,mixed,mixed);
const int strlen(string);

/* Array efuns */
const string *regexp(string *, string);
const int sizeof(mixed *);
const int member_array(mixed, mixed *);
const mixed *allocate(int,int|void,...);
const mixed *array_of_index(mixed *,int);
const mixed *aggregate(mixed|void,mixed|void,...);
side_fx mixed *sum_arrays(function,mixed *,...);
side_fx mixed *sort_array(mixed *,function|int|void,...); /* use zero for smartsort */
side_fx mixed *filter_array(mixed *, function|int|string, ...);
side_fx mixed *map_array(mixed *, function|int|string, ...);
side_fx int search_array(mixed *,function|int|string, ...);

/* save/restore functions */
side_fx int restore_object(string);
string save_object();
const mixed decode_value(string);
const string code_value(mixed,int|void);

/* uid functions */
side_fx int export_uid(object);
string geteuid(object default: F_THIS_OBJECT);
string getuid(object default: F_THIS_OBJECT);
side_fx int seteuid(string|int);

/* "command" functions */
object this_player();
side_fx object set_this_player(object);
string query_verb();
side_fx int command(string, void|object);
side_fx void add_action(string,function, void|int);
side_fx void disable_commands();
side_fx void enable_commands();
mixed *query_actions(object, object|void);

/* Output functions */
side_fx void tell_room(object, string, void|object *);
side_fx void write(mixed);

/* File efuns */
string combine_path(string,string|void);
int file_length(string);
side_fx int mkdir(string);
side_fx void log_file(string, string);
side_fx int write_bytes(string, int, string);
side_fx int write_file(string, string);
side_fx int rename(string, string);
string tail(string);
side_fx int cindent(string);
int file_size(string);
string *get_dir(string, int|void);
string read_bytes(string, void|int, void|int);
string read_file(string, void|int, void|int);
side_fx int rm(string);
side_fx int rmdir(string);
mixed *file_stat(string);

/* Mapping efuns */
side_fx mapping m_set_default(mapping,mixed);	/* H H */
mixed m_get_default(mapping);
side_fx mapping sum_mappings(mapping,mapping,function|int,function|int,function|int);
side_fx mapping m_cleanup(mapping);
side_fx mapping filter_mapping(mapping, function|int|string, ...);
side_fx mapping m_delete(mapping, mixed);
const mixed *m_aggregate(mixed|void,mixed|void,...);
const mixed *m_indices(mapping);
const int m_sizeof(mapping);
const mixed *m_values(mapping);
const list m_list(mapping);
side_fx mapping map_mapping(mapping, function|int|string, ...);
const int mappingp(mixed);
mapping mkmapping(mixed *, mixed *);
const mapping solidify_mapping(mapping);

/* lists */
const list mklist(mixed *); 
const mixed *indices(list|mapping);
const list l_delete(list,mixed);
const int l_sizeof(list);
const int listp(mixed);
const mixed *l_aggregate(mixed|void,mixed|void,...);

/* Function pointers */
side_fx mixed call_function(function *|function|int,mixed|void,...);
function get_function(object,string);
function get_lfun(object,int); /* this function is faster than get_function,
				  you don't have to use it though, the compiler
				  will optimize get_function to get_lfun when
				  possible */

function this_function();
string function_name(function);
object function_object(function);

/* floating point stuff */
#ifdef MATH
const float cos(float);
const float sin(float);
const float tan(float);
const float asin(float);
const float acos(float);
const float atan(float);
const mixed sqrt(float|int);
const float log(float);
const float pow(float, float);
const float exp(float);
const float floor(float);
const float ceil(float);
#endif

/* socket efuns */
side_fx int socket_create(int, function|void, function|void);
side_fx int socket_bind(int, int);
side_fx int socket_listen(int, function);
side_fx int socket_accept(int, function, function);
side_fx int socket_connect(int, string, function, function);
side_fx int socket_write(int, string, string|void);
side_fx int socket_close(int);
side_fx int socket_release(int, function);
side_fx int socket_acquire(int, function, function, function);
side_fx int set_socket_read(int,function);
side_fx int set_socket_write(int,function);
side_fx int set_socket_close(int,function);
side_fx int set_socket_mode(int,int);
const string socket_error(int);
string socket_address(int);
string socket_port(int);
string dump_socket_status();
side_fx int socket_from_stdin();

/* Phew, status functions */
side_fx void dumpallobj();
#ifdef malloc_SMALLOC
string dump_malloc_data();
#endif
string dump_string_data(int);
string dump_heart_beat_data(int);
string dump_prog_table_data(int);
string dump_index_table_data(int);

/* Delay efuns */
side_fx void call_out(function, int, ...);
mixed *call_out_info();
int find_call_out(function);
side_fx int remove_call_out(function);
side_fx int set_heart_beat(int);

/* Identifying functions */
const int intp(mixed);
const int objectp(mixed);
const int pointerp(mixed);
const int functionp(mixed);
const int stringp(mixed);
const int floatp(mixed);
const int zero_type(int);

/* Unix-type functions */
const string crypt(string, string|int);	/* An int as second argument ? */
const string ctime(int);
const string query_host_name();
int time();
#ifdef RUSAGE
mixed *rusage();
#endif
side_fx void shutdown();

/* Misc */
const mixed copy_value(mixed);
const mixed sum(mixed,mixed|void,...);
const mixed range(mixed,int,int);
int random(int);
side_fx void expunge();
side_fx void gc(int);
side_fx void add_worth(int, void|object);
side_fx void break_point();
const int size(mixed);
const string version();
mixed debug_info(int, mixed|void, ...);
mixed *wizlist(void|string);
string query_load_average();
side_fx void throw(mixed);
int query_num_arg(void);
mixed *get_varargs();
side_fx void set_max_eval_cost(int);
side_fx void reset_eval_cost(int);
int is_equal(mixed,mixed);

/* batch mode */
side_fx string gets();
side_fx int getchar();
side_fx void exit(int);
side_fx void sleep(int);
side_fx string popen(string);
side_fx int fork();
string getenv(string);
#ifdef HAVE_PUTENV
side_fx void putenv(string);
#endif
side_fx void perror(string);
side_fx int cd(string);
side_fx string getcwd();
side_fx int setugid(int,int);

/* database support efuns */
mixed db_get(string,string);
side_fx int db_set(string,string,string);
side_fx int db_delete(string,string);
side_fx mixed db_indices(string);

/* lacip support efuns */
#ifdef LACIP
side_fx int greyload(int,string);
side_fx int imageload(int,string);
side_fx int greysnapshot(int,int);
side_fx int greysave(int,string);
side_fx void clearscreen();
side_fx int chooseobject(int,int,int,int);
side_fx int laplace(int,int);
side_fx int prewitt(int,int);
side_fx int robert(int,int);
side_fx int robinson(int);
side_fx int sobel(int,int);
side_fx int kasvand(int,int);
side_fx int nagao(int);
side_fx int average(int,int,int);
side_fx int localaverage(int,int);
side_fx int convolution(int,mixed *,int);
side_fx int median(int, int);
side_fx int histeq(int);
side_fx int enhancement(int, int);
side_fx int threshold(int, int, int);
side_fx int labeling(int, int);
side_fx int distmap(int, int, int);
side_fx int distskel(int);
side_fx int distcad(int, int, int);
side_fx int distroute(int, int, int);
side_fx int clip(int, int, int);
side_fx int normalize(int, int);
side_fx int s_to_u(int);
side_fx int u_to_s(int);
side_fx int invert(int);
side_fx int expand(int, int, int);
side_fx int contract(int, int, int);
side_fx int thin1(int, int);
side_fx int thin2(int, int);
side_fx int thin3(int, int, int);
side_fx int thin4(int, int, int);
side_fx int shrink2(int, int);
side_fx int shrink4(int, int);
side_fx int shrink3(int, int);
side_fx int shrink1(int, int, int);
side_fx int binarize(int);
side_fx int histogram(int);
side_fx float statistics(int);
side_fx int selectthresh(int, int);
side_fx int selectstat(int);
side_fx int diffthresh(int, int);
side_fx int fft(int);
side_fx int ift(int);
side_fx int convgrey(int);
side_fx int chf(int, int, int);
side_fx int chfmagnref(int, int);
side_fx int chfvekref(int, int);
side_fx int chfveknormref(int, int);
side_fx int chfkorr(int, int);
side_fx int chfmagn(int, int);
side_fx int chfvek(int, int);
side_fx int chfveknorm(int, int);
side_fx int showchfkernel(int);
side_fx int showchfutv(int);
side_fx int gauss(int, int, int);
side_fx int hamming(int, int);
side_fx int hanning(int, int);
side_fx int lpcirc(int, int);
side_fx int hpcirc(int, int);
side_fx int bpcirc(int, int, int);
side_fx int becirc(int, int, int);
side_fx int lpwin(int, int, int);
side_fx int hpwin(int, int, int);
side_fx int bpwin(int, int, int, int, int);
side_fx int bewin(int, int, int, int, int);
side_fx int complexconj(int);
side_fx int complexnorm(int);
side_fx int complexbinfilter(int);
side_fx int corr(int, int);
side_fx int corrn(int, int);
side_fx int wiener(int, mixed *, int, int, int *, int);
side_fx int addnoise(int, int);
side_fx int cpy(int);
side_fx int copyto(int, int);
side_fx int equal(int, int);
side_fx int notequal(int, int);
side_fx int equalzero(int);
side_fx int notequalzero(int);
side_fx int add(int, int);
side_fx int sub(int, int);
side_fx int mult(int, int);
side_fx int greymask(int, int);
side_fx int imageor(int, int);
side_fx int imageand(int, int);
side_fx int colortable(int);
side_fx int rotate(int, int);
side_fx int deleteimage(int);
side_fx int show(int, int);
side_fx int unshow(int);
side_fx int whoami(int);
side_fx void info(int, int, int);
side_fx void nearest();
side_fx void linear();
side_fx void cspline();
side_fx void hrcspline();
side_fx void dbx(int);
side_fx int hough(int);
side_fx int ihough(int);
side_fx int logop(int, int *, int, int, int);
side_fx int logop4(int, mixed *, int, int, int);
side_fx int ocrextract(int, int);
side_fx int ocrselectthresh1(int, int);
side_fx int ocrselectthresh2(int, int);
side_fx int ocrdecide(int, int);
side_fx int ocrshrink(int, int);
side_fx int shuffle(int, int);
side_fx int extract(int, int);
side_fx int heap_replace(int, int, int);
side_fx int query_nr(int);
side_fx int create_heap(int, int);
side_fx void optflow(int, int, int, int, int);
side_fx int rtf(int, int);
side_fx int getval(int, int, int);
side_fx int shadkorr1(int, int, int, int, int);
side_fx int shadkorr2(int, int, int, int, int);
side_fx void closescreen(int);
side_fx void show3D(int , mixed *, int, int, int);
side_fx void openscreen();
side_fx void button_128_256();
side_fx void button_512();
#endif

==> lpc4.05.10.tar.gz: lpc4/src/func_spec.c <==
#include "config.h"
/*
 * This file specifies types and arguments for efuns.
 * An argument can have two different types with the syntax 'type1 | type2'.
 * An argument is marked as optional if it also takes the type 'void'.
 */

/*
 * These values are used by the stack machine, and can not be directly
 * called from LPC.
 */
%token F_ADD_256 F_ADD_512 F_ADD_768 F_ADD_1024 F_ADD_256X
%token F_POP_VALUE F_DUP F_MARK F_WRITE_OPCODE
%token F_PUSH_IDENTIFIER_LVALUE F_PUSH_LOCAL_VARIABLE_LVALUE
%token F_PUSH_INDEXED_LVALUE F_INDIRECT F_INDEX F_CONSTANT F_SHORT_CONSTANT
%token F_CONST0 F_CONST1 F_PUSH_LTOSVAL F_PUSH_LTOSVAL2 F_PUSH_COST F_SWAP
%token F_LOCAL_NAME F_CONST_1 F_BYTE F_NEG_BYTE F_SHORT
%token F_BRANCH F_BRANCH_WHEN_ZERO F_BRANCH_WHEN_NON_ZERO
%token F_SHORT_BRANCH F_SHORT_BRANCH_WHEN_ZERO F_SHORT_BRANCH_WHEN_NON_ZERO

/*
 * These are the predefined functions that can be accessed from LPC.
 */

%token F_IDENTIFIER F_RETURN F_STRING F_SHORT_STRING
%token F_INC F_DEC F_POST_INC F_POST_DEC
%token F_INC_AND_POP F_DEC_AND_POP F_POP_N_ELEMS F_DUMB_RETURN
%token F_NUMBER F_ASSIGN F_ASSIGN_AND_POP F_ADD F_ADD_INT F_SUBTRACT F_MULTIPLY

%token F_DIVIDE F_LT F_GT F_EQ F_GE F_LE F_NE F_NEGATE F_NOT F_MOD
%token F_COMPL F_AND F_OR F_XOR F_LSH F_RSH F_LAND F_LOR

%token F_SWITCH F_SSCANF F_CAST_TO_OBJECT F_CAST_TO_REGEXP
%token F_INC_LOOP F_DEC_LOOP F_CAST_TO_STRING
%token F_INC_NEQ_LOOP F_DEC_NEQ_LOOP F_SWAP_VARIABLES

%token F_CATCH F_CAST_TO_FUNCTION F_PUSH_ARRAY
%token F_FOREACH F_CAST_TO_INT F_CAST_TO_FLOAT F_FLOAT
%token F_PUSH_SIMUL_EFUN F_TAILRECURSE
%token F_CONSTANT_FUNCTION F_SHORT_CONSTANT_FUNCTION
/* %token F_PARSE_COMMAND */

/* Object handling */
object this_object();
side_fx object clone_object(string);
side_fx void destruct(object|void);
side_fx void move_object(object);
side_fx string make_object(string);
side_fx object present(string|object, object default: F_THIS_OBJECT);
object first_inventory(object default: F_THIS_OBJECT);
object next_inventory(object default: F_THIS_OBJECT);
object *all_inventory(object default: F_THIS_OBJECT);
object *deep_inventory(object default: F_THIS_OBJECT);
object environment(void|object);
object next_clone(object|string);
int created(object);
int object_cpu(object);
int clone_number(object);
object *top_cpu(void);
object master();
object previous_object();
object *previous_objects();
object initiating_object();
string file_name(object default: F_THIS_OBJECT);

/* Object hash */
string hash_name(object);
object find_object(string);

/* Program handling */
string function_exists(string, object default: F_THIS_OBJECT);
string *inherit_list(object default: F_THIS_OBJECT);
side_fx int load(string);
side_fx int update(string);

/* String functions */
const string *explode(string, string);
const string implode(string *, string);
#ifdef USE_SPRINTF
string sprintf(string, ...);
#endif
const string lower_case(string);
const string capitalize(string);
const int strstr(string,string,void|int);
const string upper_case(string);
const mixed replace(string|mixed *,mixed,mixed);
const int strlen(string);

/* Array efuns */
const string *regexp(string *, regular_expression);
const int sizeof(mixed *);
const int member_array(mixed, mixed *);
const mixed *allocate(int,int|void,...);
const mixed *array_of_index(mixed *,int);
const mixed *aggregate(mixed|void,mixed|void,...);
side_fx mixed *sum_arrays(function,mixed *,...);
side_fx mixed *sort_array(mixed *,function|int|void,...); /* use zero for smartsort */
side_fx mixed *filter_array(mixed *, function|int|string, ...);
side_fx mixed *map_array(mixed *, function|int|string, ...);
side_fx int search_array(mixed *,function|int|string, ...);

/* save/restore functions */
side_fx int restore_object(string);
string save_object();
const mixed decode_value(string);
const string code_value(mixed,int|void);

/* uid functions */
side_fx int export_uid(object);
string geteuid(object default: F_THIS_OBJECT);
string getuid(object default: F_THIS_OBJECT);
side_fx int seteuid(string|int);

/* "command" functions */
object this_player();
side_fx object set_this_player(object);
string query_verb();
side_fx int command(string, void|object);
side_fx void add_action(string,function, void|int);
side_fx void disable_commands();
side_fx void enable_commands();
mixed *query_actions(object, object|void);

/* Output functions */
side_fx void tell_room(object, string, void|object *);
side_fx void write(mixed);

/* File efuns */
string combine_path(string,string|void);
int file_length(string);
side_fx int mkdir(string);
side_fx void log_file(string, string);
side_fx int write_bytes(string, int, string);
side_fx int write_file(string, string);
side_fx int rename(string, string);
string tail(string);
side_fx int cindent(string);
int file_size(string);
string *get_dir(string, int|void);
string read_bytes(string, void|int, void|int);
string read_file(string, void|int, void|int);
side_fx int rm(string);
side_fx int rmdir(string);
mixed *file_stat(string);

/* Mapping efuns */
side_fx mapping m_set_default(mapping,mixed);	/* H H */
mixed m_get_default(mapping);
side_fx mapping sum_mappings(mapping,mapping,function|int,function|int,function|int);
side_fx mapping m_cleanup(mapping);
side_fx mapping filter_mapping(mapping, function|int|string, ...);
side_fx mapping m_delete(mapping, mixed);
const mapping m_aggregate(mixed|void,mixed|void,...);
const mixed *m_indices(mapping);
const int m_sizeof(mapping);
const mixed *m_values(mapping);
const list m_list(mapping);
side_fx mapping map_mapping(mapping, function|int|string, ...);
const int mappingp(mixed);
mapping mkmapping(mixed *, mixed *);
const mapping solidify_mapping(mapping);

/* lists */
const list mklist(mixed *); 
const mixed *indices(list|mapping);
const list l_delete(list,mixed);
const int l_sizeof(list);
const int listp(mixed);
const list l_aggregate(mixed|void,mixed|void,...);

/* Function pointers */
side_fx mixed call_function(function *|function|int,mixed|void,...);
function get_function(object,string);
function get_lfun(object,int); /* this function is faster than get_function,
				  you don't have to use it though, the compiler
				  will optimize get_function to get_lfun when
				  possible */

function this_function();
string function_name(function);
object function_object(function);

/* floating point stuff */
#ifdef MATH
const float cos(float);
const float sin(float);
const float tan(float);
const float asin(float);
const float acos(float);
const float atan(float);
const mixed sqrt(float|int);
const float log(float);
const float pow(float, float);
const float exp(float);
const float floor(float);
const float ceil(float);
#endif

/* socket efuns */
side_fx int socket_create(int, function|void, function|void);
side_fx int socket_bind(int, int);
side_fx int socket_listen(int, function);
side_fx int socket_accept(int, function, function);
side_fx int socket_connect(int, string, function, function);
side_fx int socket_write(int, string, string|void);
side_fx int socket_close(int);
side_fx int socket_release(int, function);
side_fx int socket_acquire(int, function, function, function);
side_fx int set_socket_read(int,function);
side_fx int set_socket_write(int,function);
side_fx int set_socket_close(int,function);
side_fx int set_socket_mode(int,int);
const string socket_error(int);
string socket_address(int);
string socket_port(int);
string dump_socket_status();
side_fx int socket_from_stdin();

/* Phew, status functions */
string dumpallobj();
string dump_malloc_data();
string dump_string_data(int);
string dump_heart_beat_data(int);
string dump_prog_table_data(int);
string dump_index_table_data(int);

/* Delay efuns */
side_fx void call_out(function, int, ...);
mixed *call_out_info();
int find_call_out(function);
side_fx int remove_call_out(function);
side_fx int set_heart_beat(int);

/* Identifying functions */
const int intp(mixed);
const int objectp(mixed);
const int pointerp(mixed);
const int functionp(mixed);
const int stringp(mixed);
const int floatp(mixed);
const int zero_type(int);
const int regular_expressionp(mixed);

/* Unix-type functions */
const string crypt(string, string|int);	/* An int as second argument ? */
const string ctime(int);
const string query_host_name();
int time();
#ifdef HAVE_GETRUSAGE
mixed *rusage();
#endif
side_fx void shutdown();

/* Misc */
const mixed copy_value(mixed);
const mixed sum(mixed,mixed|void,...);
const mixed range(mixed,int,int);
int random(int);
side_fx void expunge();
side_fx void gc(int);
side_fx void add_worth(int, void|object);
side_fx void break_point();
const int size(mixed);
const string version();
mixed debug_info(int, mixed|void, ...);
mixed *wizlist(void|string);
string query_load_average();
side_fx void throw(mixed);
int query_num_arg(void);
mixed *get_varargs();
side_fx void set_max_eval_cost(int);
side_fx void reset_eval_cost(int);
int is_equal(mixed,mixed);

/* batch mode */
side_fx string gets();
side_fx int getchar();
side_fx void exit(int);
side_fx void sleep(int);
side_fx string popen(string);
side_fx int fork();
string getenv(string);
#ifdef HAVE_PUTENV
side_fx void putenv(string);
#endif
side_fx void perror(string);
side_fx int cd(string);
side_fx string getcwd();
side_fx int setugid(int,int);

/* database support efuns */
mixed db_get(string,string);
side_fx int db_set(string,string,string);
side_fx int db_delete(string,string);
side_fx mixed db_indices(string);

/* lacip support efuns */
#ifdef LACIP
side_fx int greyload(int,string);
side_fx int imageload(int,string);
side_fx int greysnapshot(int,int);
side_fx int greysave(int,string);
side_fx void clearscreen();
side_fx int chooseobject(int,int,int,int);
side_fx int laplace(int,int);
side_fx int prewitt(int,int);
side_fx int robert(int,int);
side_fx int robinson(int);
side_fx int sobel(int,int);
side_fx int kasvand(int,int);
side_fx int nagao(int);
side_fx int average(int,int,int);
side_fx int localaverage(int,int);
side_fx int convolution(int,mixed *,int);
side_fx int median(int, int);
side_fx int histeq(int);
side_fx int enhancement(int, int);
side_fx int threshold(int, int, int);
side_fx int labeling(int, int);
side_fx int distmap(int, int, int);
side_fx int distskel(int);
side_fx int distcad(int, int, int);
side_fx int distroute(int, int, int);
side_fx int clip(int, int, int);
side_fx int normalize(int, int);
side_fx int s_to_u(int);
side_fx int u_to_s(int);
side_fx int invert(int);
side_fx int expand(int, int, int);
side_fx int contract(int, int, int);
side_fx int thin1(int, int);
side_fx int thin2(int, int);
side_fx int thin3(int, int, int);
side_fx int thin4(int, int, int);
side_fx int shrink2(int, int);
side_fx int shrink4(int, int);
side_fx int shrink3(int, int);
side_fx int shrink1(int, int, int);
side_fx int binarize(int);
side_fx int histogram(int);
side_fx float statistics(int);
side_fx int selectthresh(int, int);
side_fx int selectstat(int);
side_fx int diffthresh(int, int);
side_fx int fft(int);
side_fx int ift(int);
side_fx int convgrey(int);
side_fx int chf(int, int, int);
side_fx int chfmagnref(int, int);
side_fx int chfvekref(int, int);
side_fx int chfveknormref(int, int);
side_fx int chfkorr(int, int);
side_fx int chfmagn(int, int);
side_fx int chfvek(int, int);
side_fx int chfveknorm(int, int);
side_fx int showchfkernel(int);
side_fx int showchfutv(int);
side_fx int gauss(int, int, int);
side_fx int hamming(int, int);
side_fx int hanning(int, int);
side_fx int lpcirc(int, int);
side_fx int hpcirc(int, int);
side_fx int bpcirc(int, int, int);
side_fx int becirc(int, int, int);
side_fx int lpwin(int, int, int);
side_fx int hpwin(int, int, int);
side_fx int bpwin(int, int, int, int, int);
side_fx int bewin(int, int, int, int, int);
side_fx int complexconj(int);
side_fx int complexnorm(int);
side_fx int complexbinfilter(int);
side_fx int corr(int, int);
side_fx int corrn(int, int);
side_fx int wiener(int, mixed *, int, int, int *, int);
side_fx int addnoise(int, int);
side_fx int cpy(int);
side_fx int copyto(int, int);
side_fx int equal(int, int);
side_fx int notequal(int, int);
side_fx int equalzero(int);
side_fx int notequalzero(int);
side_fx int add(int, int);
side_fx int sub(int, int);
side_fx int mult(int, int);
side_fx int greymask(int, int);
side_fx int imageor(int, int);
side_fx int imageand(int, int);
side_fx int colortable(int);
side_fx int rotate(int, int);
side_fx int deleteimage(int);
side_fx int show(int, int);
side_fx int unshow(int);
side_fx int whoami(int);
side_fx void info(int, int, int);
side_fx void nearest();
side_fx void linear();
side_fx void cspline();
side_fx void hrcspline();
side_fx void dbx(int);
side_fx int hough(int);
side_fx int ihough(int);
side_fx int logop(int, int *, int, int, int);
side_fx int logop4(int, mixed *, int, int, int);
side_fx int ocrextract(int, int);
side_fx int ocrselectthresh1(int, int);
side_fx int ocrselectthresh2(int, int);
side_fx int ocrdecide(int, int);
side_fx int ocrshrink(int, int);
side_fx int shuffle(int, int);
side_fx int extract(int, int);
side_fx int heap_replace(int, int, int);
side_fx int query_nr(int);
side_fx int create_heap(int, int);
side_fx void optflow(int, int, int, int, int);
side_fx int rtf(int, int);
side_fx int getval(int, int, int);
side_fx int shadkorr1(int, int, int, int, int);
side_fx int shadkorr2(int, int, int, int, int);
side_fx void closescreen(int);
side_fx void show3D(int , mixed *, int, int, int);
side_fx void openscreen();
side_fx void button_128_256();
side_fx void button_512();
#endif
